@@ -15,8 +15,8 @@ from .pymd_engine import convert_markdown
 __all__ = [
     "base",
     "index",
-    "indexed_article_series",
-    "indexed_articles",
+    "date_indexed_article_series",
+    "date_indexed_articles",
     "article_series",
     "article",
     "md_context",
@@ -65,16 +65,20 @@ def index(template, audit_builder: AuditBuilder):
     return {}
 
 
-def indexed_article_series(template, dir_path, drop_hidden=True):
+def is_valid_series_directory(path: Path) -> bool:
+    return (
+        path.is_dir() and (path / "index.md").exists() and not path.name.startswith("_")
+    )
+
+
+def date_indexed_article_series(template, dir_path, drop_hidden=True):
     "Sort article series by date"
     series_dict = {
         "series": sorted(
             [
-                article_series(a, is_path=True)
-                for a in dir_path.iterdir()
-                if a.is_dir()  # sub-directory
-                if (a / "index.md").exists()
-                if not a.name.startswith("_")  # not partial template
+                article_series(series_path, is_path=True)
+                for series_path in dir_path.iterdir()
+                if is_valid_series_directory(path=series_path)
             ],
             key=lambda d: dateparser.parse(d["date"]),
             reverse=True,
@@ -94,7 +98,9 @@ def indexed_article_series(template, dir_path, drop_hidden=True):
     return series_dict
 
 
-def indexed_articles(template, dir_path, audit_builder: AuditBuilder, with_series=True):
+def date_indexed_articles(
+    template, dir_path, audit_builder: AuditBuilder, with_series=True
+):
     "Sort articles by date"
     if audit_builder.active:
         if audit_builder.auditer.recheck and audit_builder.auditer.is_no_diff(template):
@@ -113,7 +119,7 @@ def indexed_articles(template, dir_path, audit_builder: AuditBuilder, with_serie
         )
     }
     if with_series:
-        series_dict = indexed_article_series(template, dir_path)
+        series_dict = date_indexed_article_series(template, dir_path)
         articles_dict = {
             "articles": sorted(
                 [
@@ -127,6 +133,12 @@ def indexed_articles(template, dir_path, audit_builder: AuditBuilder, with_serie
     return articles_dict
 
 
+def validate_metadata(metadata, template):
+    required_keys = {"title", "desc", "date"}
+    if not all(k in metadata for k in required_keys):
+        raise ValueError(f"{template=} missing one or more of {required_keys=}")
+
+
 def article_series(template, is_path=False):
     """A context providing the URL, time last modified, and all frontmatter metadata"""
     Log(f"- Prepping {template} (article series)")
@@ -139,11 +151,7 @@ def article_series(template, is_path=False):
         )
     md_content = frontmatter.load(template_index_path)
     metadata = md_content.metadata
-    required_keys = {"title", "desc", "date"}
-    if not all(k in metadata for k in required_keys):
-        raise ValueError(
-            f"{template=} missing one or more of {required_keys=} in index.md"
-        )
+    validate_metadata(metadata=metadata, template=template)
     return {"url": template_path.stem, "mtime": fmt_mtime(template_path), **metadata}
 
 
@@ -160,12 +168,26 @@ def article(template, audit_builder: AuditBuilder, is_path=False):
         raise ValueError("Metadata is not supported for non-markdown articles")
     md_content = frontmatter.load(template_path)
     metadata = md_content.metadata
-    required_keys = {"title", "desc", "date"}
-    if not all(k in metadata for k in required_keys):
-        raise ValueError(f"{template=} missing one or more of {required_keys=}")
+    validate_metadata(metadata=metadata, template=template)
     return {"url": template_path.stem, "mtime": fmt_mtime(template_path), **metadata}
 
 
+def make_toc(index_path: Path) -> list[tuple[str, str]]:
+    toc_list = [
+        (
+            matter.metadata.get("order", -1),
+            matter.metadata["title"],
+            f"{index_path.parent.stem}-{series_entry.stem}",
+        )
+        for series_entry in index_path.parent.iterdir()
+        if series_entry != index_path
+        if not series_entry.is_dir()
+        for matter in [frontmatter.load(series_entry)]
+    ]
+    toc_list.sort()
+    return toc_list
+
+
 def md_context(template, audit_builder: AuditBuilder):
     """A context providing the parsed HTML and scanning it for KaTeX"""
     if audit_builder.active:
@@ -177,4 +199,11 @@ def md_context(template, audit_builder: AuditBuilder):
     md_content = frontmatter.load(template.filename)
     html_content = convert_markdown(md_content.content)
     has_katex = """<span class="katex">""" in html_content
-    return {"post_content_html": html_content, "katex": has_katex}
+    series_toc_magic = "%series_toc%"
+    has_series_toc = series_toc_magic in html_content
+    extra_flags = {"katex": has_katex}
+    if has_series_toc:
+        html_content = html_content.replace(series_toc_magic, "")
+        series_toc_list = make_toc(index_path=Path(template.filename))
+        extra_flags["series_toc"] = series_toc_list
+    return {"post_content_html": html_content, **extra_flags}
